==> material-react-table-2.0.1.tgz: package/locales/ar/index.esm.js <==
const MRT_Localization_AR = {
    actions: 'إجراءات',
    and: 'و',
    cancel: 'إلغاء',
    changeFilterMode: 'تغيير وضع المرشح',
    changeSearchMode: 'تغيير وضع البحث',
    clearFilter: 'إعادة تعين المرشح',
    clearSearch: 'إعادة تعيين البحث',
    clearSort: 'إعادة تعيين الفرز',
    clickToCopy: 'انقر للنسخ',
    collapse: 'إخفاء',
    collapseAll: 'إخفاء الكل',
    columnActions: 'إجراءات العمود',
    copiedToClipboard: 'نسخ إلى الحافظة',
    dropToGroupBy: 'أفلت للمجموعة حسب {column}',
    edit: 'تعديل',
    expand: 'إظهار',
    expandAll: 'إظهار الكل',
    filterArrIncludes: 'يشمل',
    filterArrIncludesAll: 'يشمل الجميع',
    filterArrIncludesSome: 'يشمل',
    filterBetween: 'بين',
    filterBetweenInclusive: 'بين الشمول',
    filterByColumn: 'مصنف بواسطة {column}',
    filterContains: 'يتضمن',
    filterEmpty: 'فارغ',
    filterEndsWith: 'ينتهي بـ',
    filterEquals: 'يساوي',
    filterEqualsString: 'يساوي',
    filterFuzzy: 'غامض',
    filterGreaterThan: 'أكثر من',
    filterGreaterThanOrEqualTo: 'أكبر من أو يساوي',
    filterInNumberRange: 'بين',
    filterIncludesString: 'يتضمن',
    filterIncludesStringSensitive: 'يتضمن',
    filterLessThan: 'أقل من',
    filterLessThanOrEqualTo: 'أقل من أو يساوي',
    filterMode: 'وضع التصفية: {filterType}',
    filterNotEmpty: 'ليس فارغًا',
    filterNotEquals: 'لا يساوي',
    filterStartsWith: ' يبدا ب',
    filterWeakEquals: 'يساوي',
    filteringByColumn: 'التصفية حسب {column} - {filterType} {filterValue}',
    goToFirstPage: 'الصفحة الأولى',
    goToLastPage: 'الصفحة الأخيرة',
    goToNextPage: 'الصفحة التالية',
    goToPreviousPage: 'الصفحة السابقة',
    grab: 'أمسك',
    groupByColumn: 'مجموعة من {column}',
    groupedBy: 'مجمعة حسب ',
    hideAll: 'إخفاء الكل',
    hideColumn: 'إخفاء {column} العمود',
    max: 'الأعلى',
    min: 'الأقل',
    move: 'حرك',
    noRecordsToDisplay: 'لا سجلات لعرضها',
    noResultsFound: 'لم يتم العثور على نتائج',
    of: 'ل',
    or: 'أو',
    pin: 'تثبيت',
    pinToLeft: 'تثبيت جهة اليسار',
    pinToRight: 'تثبيت على اليمين',
    resetColumnSize: 'Reset column size',
    resetOrder: 'إعادة تعيين',
    rowActions: 'إجراءات الصف',
    rowNumber: '#',
    rowNumbers: 'أرقام الصفوف',
    rowsPerPage: 'عدد الصفوف في الصفحة',
    save: 'حفظ',
    search: 'بحث',
    selectedCountOfRowCountRowsSelected: '{selectedCount} ل {rowCount} row(s) المحدد',
    select: 'اخيار',
    showAll: 'عرض الكل',
    showAllColumns: 'إظهار كافة الأعمدة',
    showHideColumns: 'إظهار / إخفاء الأعمدة',
    showHideFilters: 'إظهار / إخفاء المرشحات',
    showHideSearch: 'إظهار / إخفاء البحث',
    sortByColumnAsc: 'فرز  {column} تصاعدي',
    sortByColumnDesc: 'فرز {column} تنازلي',
    sortedByColumnAsc: 'مرتبة حسب {column} تصاعدي',
    sortedByColumnDesc: 'مرتبة حسب {column} تنازلي',
    thenBy: ', ثم بواسطة ',
    toggleDensity: 'تبديل الكثافة',
    toggleFullScreen: 'ملء الشاشة',
    toggleSelectAll: 'تبديل حدد الكل',
    toggleSelectRow: 'تبديل تحديد الصف',
    toggleVisibility: 'تبديل الرؤية',
    ungroupByColumn: 'فك التجميع حسب {column}',
    unpin: 'عدم التثبيت',
    unpinAll: 'عدم تثبيت الكل',
};

export { MRT_Localization_AR };

==> material-react-table-2.0.4.tgz: package/locales/ar/index.esm.js <==
const MRT_Localization_AR = {
    actions: 'إجراءات',
    and: 'و',
    cancel: 'إلغاء',
    changeFilterMode: 'تغيير وضع المرشح',
    changeSearchMode: 'تغيير وضع البحث',
    clearFilter: 'إعادة تعين المرشح',
    clearSearch: 'إعادة تعيين البحث',
    clearSort: 'إعادة تعيين الفرز',
    clickToCopy: 'انقر للنسخ',
    collapse: 'إخفاء',
    collapseAll: 'إخفاء الكل',
    columnActions: 'إجراءات العمود',
    copiedToClipboard: 'نسخ إلى الحافظة',
    dropToGroupBy: 'أفلت للمجموعة حسب {column}',
    edit: 'تعديل',
    expand: 'إظهار',
    expandAll: 'إظهار الكل',
    filterArrIncludes: 'يشمل',
    filterArrIncludesAll: 'يشمل الجميع',
    filterArrIncludesSome: 'يشمل',
    filterBetween: 'بين',
    filterBetweenInclusive: 'بين الشمول',
    filterByColumn: 'مصنف بواسطة {column}',
    filterContains: 'يتضمن',
    filterEmpty: 'فارغ',
    filterEndsWith: 'ينتهي بـ',
    filterEquals: 'يساوي',
    filterEqualsString: 'يساوي',
    filterFuzzy: 'غامض',
    filterGreaterThan: 'أكثر من',
    filterGreaterThanOrEqualTo: 'أكبر من أو يساوي',
    filterInNumberRange: 'بين',
    filterIncludesString: 'يتضمن',
    filterIncludesStringSensitive: 'يتضمن',
    filterLessThan: 'أقل من',
    filterLessThanOrEqualTo: 'أقل من أو يساوي',
    filterMode: 'وضع التصفية: {filterType}',
    filterNotEmpty: 'ليس فارغًا',
    filterNotEquals: 'لا يساوي',
    filterStartsWith: ' يبدا ب',
    filterWeakEquals: 'يساوي',
    filteringByColumn: 'التصفية حسب {column} - {filterType} {filterValue}',
    goToFirstPage: 'الصفحة الأولى',
    goToLastPage: 'الصفحة الأخيرة',
    goToNextPage: 'الصفحة التالية',
    goToPreviousPage: 'الصفحة السابقة',
    grab: 'أمسك',
    groupByColumn: 'مجموعة من {column}',
    groupedBy: 'مجمعة حسب ',
    hideAll: 'إخفاء الكل',
    hideColumn: 'إخفاء {column} العمود',
    max: 'الأعلى',
    min: 'الأقل',
    move: 'حرك',
    noRecordsToDisplay: 'لا سجلات لعرضها',
    noResultsFound: 'لم يتم العثور على نتائج',
    of: 'ل',
    or: 'أو',
    pin: 'تثبيت',
    pinToLeft: 'تثبيت جهة اليسار',
    pinToRight: 'تثبيت على اليمين',
    resetColumnSize: 'إعادة تعيين حجم العمود',
    resetOrder: 'إعادة تعيين',
    rowActions: 'إجراءات الصف',
    rowNumber: '#',
    rowNumbers: 'أرقام الصفوف',
    rowsPerPage: 'عدد الصفوف في الصفحة',
    save: 'حفظ',
    search: 'بحث',
    selectedCountOfRowCountRowsSelected: '{selectedCount} ل {rowCount} row(s) المحدد',
    select: 'اختيار',
    showAll: 'عرض الكل',
    showAllColumns: 'إظهار كافة الأعمدة',
    showHideColumns: 'إظهار / إخفاء الأعمدة',
    showHideFilters: 'إظهار / إخفاء المرشحات',
    showHideSearch: 'إظهار / إخفاء البحث',
    sortByColumnAsc: 'فرز  {column} تصاعدي',
    sortByColumnDesc: 'فرز {column} تنازلي',
    sortedByColumnAsc: 'مرتبة حسب {column} تصاعدي',
    sortedByColumnDesc: 'مرتبة حسب {column} تنازلي',
    thenBy: ', ثم بواسطة ',
    toggleDensity: 'تبديل الكثافة',
    toggleFullScreen: 'ملء الشاشة',
    toggleSelectAll: 'تبديل تحديد الكل',
    toggleSelectRow: 'تبديل تحديد الصف',
    toggleVisibility: 'تبديل الرؤية',
    ungroupByColumn: 'فك التجميع حسب {column}',
    unpin: 'عدم التثبيت',
    unpinAll: 'عدم تثبيت الكل',
};

export { MRT_Localization_AR };
